aboutsummaryrefslogtreecommitdiffstats
path: root/OpenKeychain/src/test
diff options
context:
space:
mode:
authorDominik Schürmann <dominik@dominikschuermann.de>2015-06-29 20:48:11 +0200
committerDominik Schürmann <dominik@dominikschuermann.de>2015-06-29 20:48:11 +0200
commita9c606d49bf7d4e7a30b7265cd1fb04ff1c3c01c (patch)
tree9d3bf539e11bfd7f9d1d4d58fc046aa27e180897 /OpenKeychain/src/test
parentcf59a8fc308a8988c949c1175c963977f84ee653 (diff)
downloadopen-keychain-a9c606d49bf7d4e7a30b7265cd1fb04ff1c3c01c.tar.gz
open-keychain-a9c606d49bf7d4e7a30b7265cd1fb04ff1c3c01c.tar.bz2
open-keychain-a9c606d49bf7d4e7a30b7265cd1fb04ff1c3c01c.zip
Create key wizard for blank YubiKey
Diffstat (limited to 'OpenKeychain/src/test')
-rw-r--r--OpenKeychain/src/test/java/org/sufficientlysecure/keychain/pgp/PgpKeyOperationTest.java7
1 files changed, 3 insertions, 4 deletions
diff --git a/OpenKeychain/src/test/java/org/sufficientlysecure/keychain/pgp/PgpKeyOperationTest.java b/OpenKeychain/src/test/java/org/sufficientlysecure/keychain/pgp/PgpKeyOperationTest.java
index d92e90d6a..fcb458fbe 100644
--- a/OpenKeychain/src/test/java/org/sufficientlysecure/keychain/pgp/PgpKeyOperationTest.java
+++ b/OpenKeychain/src/test/java/org/sufficientlysecure/keychain/pgp/PgpKeyOperationTest.java
@@ -41,7 +41,6 @@ import org.spongycastle.bcpg.UserIDPacket;
import org.spongycastle.bcpg.sig.KeyFlags;
import org.spongycastle.jce.provider.BouncyCastleProvider;
import org.spongycastle.openpgp.PGPSignature;
-import org.sufficientlysecure.keychain.BuildConfig;
import org.sufficientlysecure.keychain.WorkaroundBuildConfig;
import org.sufficientlysecure.keychain.operations.results.OperationResult.LogType;
import org.sufficientlysecure.keychain.operations.results.OperationResult.OperationLog;
@@ -847,7 +846,7 @@ public class PgpKeyOperationTest {
parcel, cryptoInput, LogType.MSG_MF_ERROR_BAD_NFC_ALGO);
}
- { // keytocard should return a pending NFC_KEYTOCARD result when presented with the RSA-2048
+ { // keytocard should return a pending NFC_MOVE_KEY_TO_CARD result when presented with the RSA-2048
// key, and then make key divert-to-card when it gets a serial in the cryptoInputParcel.
long keyId = KeyringTestingHelper.getSubkeyId(ring, 2);
parcel.reset();
@@ -858,8 +857,8 @@ public class PgpKeyOperationTest {
PgpKeyOperation op = new PgpKeyOperation(null);
PgpEditKeyResult result = op.modifySecretKeyRing(secretRing, cryptoInput, parcel);
Assert.assertTrue("keytocard operation should be pending", result.isPending());
- Assert.assertEquals("required input should be RequiredInputType.NFC_KEYTOCARD",
- result.getRequiredInputParcel().mType, RequiredInputType.NFC_KEYTOCARD);
+ Assert.assertEquals("required input should be RequiredInputType.NFC_MOVE_KEY_TO_CARD",
+ result.getRequiredInputParcel().mType, RequiredInputType.NFC_MOVE_KEY_TO_CARD);
// Create a cryptoInputParcel that matches what the NFCOperationActivity would return.
byte[] keyIdBytes = new byte[8];